diff src/globals.h @ 21703:22583b9d4efd v8.2.1401

patch 8.2.1401: cannot jump to the last used tabpage Commit: https://github.com/vim/vim/commit/62a232506d06f6d1b3b7271801c907d6294dfe84 Author: Bram Moolenaar <Bram@vim.org> Date: Sun Aug 9 14:04:42 2020 +0200 patch 8.2.1401: cannot jump to the last used tabpage Problem: Cannot jump to the last used tabpage. Solution: Add g<Tab> and tabpagnr('#'). (Yegappan Lakshmanan, closes https://github.com/vim/vim/issues/6661, neovim #11626)
author Bram Moolenaar <Bram@vim.org>
date Sun, 09 Aug 2020 14:15:04 +0200
parents 7b5b9558500a
children 35921b7fc07a
line wrap: on
line diff
--- a/src/globals.h
+++ b/src/globals.h
@@ -725,10 +725,12 @@ EXTERN frame_T	*topframe;	// top of the 
 
 /*
  * Tab pages are alternative topframes.  "first_tabpage" points to the first
  * one in the list, "curtab" is the current one.
  */
 EXTERN tabpage_T    *first_tabpage;
 EXTERN tabpage_T    *curtab;
+EXTERN tabpage_T    *lastused_tabpage;
 EXTERN int	    redraw_tabline INIT(= FALSE);  // need to redraw tabline
 
 /*
@@ -725,10 +725,12 @@ EXTERN frame_T	*topframe;	// top of the 
 /*
  * Tab pages are alternative topframes.  "first_tabpage" points to the first
- * one in the list, "curtab" is the current one.
+ * one in the list, "curtab" is the current one. "lastused_tabpage" is the
+ * last used one.
  */
 EXTERN tabpage_T    *first_tabpage;